| computeDR | R Documentation |
This function computes deviance residuals from a null Cox model. By default
it delegates to survival::coxph(), but a high-performance C++ engine is
also available for large in-memory or bigmemory::big.matrix design
matrices.
computeDR(
time,
time2,
event,
type,
origin,
typeres = "deviance",
collapse,
weighted,
scaleY = TRUE,
plot = FALSE,
engine = c("survival", "cpp", "qcpp"),
method = c("efron", "breslow"),
X = NULL,
coef = NULL,
eta = NULL,
center = NULL,
scale = NULL
)
time |
for right censored data, this is the follow up time. For interval data, the first argument is the starting time for the interval. |
time2 |
The status indicator, normally 0=alive, 1=dead. Other choices
are |
event |
ending time of the interval for interval censored or counting
process data only. Intervals are assumed to be open on the left and closed
on the right, |
type |
character string specifying the type of censoring. Possible
values are |
origin |
for counting process data, the hazard function origin. This option was intended to be used in conjunction with a model containing time dependent strata in order to align the subjects properly when they cross over from one strata to another, but it has rarely proven useful. |
typeres |
character string indicating the type of residual desired.
Possible values are |
collapse |
vector indicating which rows to collapse (sum) over. In
time-dependent models more than one row data can pertain to a single
individual. If there were 4 individuals represented by 3, 1, 2 and 4 rows of
data respectively, then |
weighted |
if |
scaleY |
Should the |
plot |
Should the survival function be plotted ? |
engine |
Either |
method |
Tie handling to use with |
X |
Optional design matrix used to compute the linear predictor when
|
coef |
Optional coefficient vector associated with |
eta |
Optional precomputed linear predictor passed directly to the C++ engine. |
center, scale |
Optional centring and scaling vectors applied to |
Residuals from a null model fit. When engine = "cpp", the returned
vector has attributes "martingale", "cumhaz", and
"linear_predictor".
Frédéric Bertrand
frederic.bertrand@lecnam.net
https://fbertran.github.io/homepage/
Bastien, P., Bertrand, F., Meyer, N., and Maumy-Bertrand, M. (2015). Deviance residuals-based sparse PLS and sparse kernel PLS for binary classification and survival analysis. BMC Bioinformatics, 16, 211.
Therneau, T.M., Grambsch, P.M. (2000). Modeling Survival Data: Extending the Cox Model. Springer.
coxph
data(micro.censure, package = "bigPLScox")
Y_train_micro <- micro.censure$survyear[1:80]
C_train_micro <- micro.censure$DC[1:80]
Y_DR <- computeDR(Y_train_micro,C_train_micro)
Y_DR <- computeDR(Y_train_micro,C_train_micro,plot=TRUE)
Y_cpp <- computeDR(
Y_train_micro,
C_train_micro,
engine = "cpp",
eta = rep(0, length(Y_train_micro))
)
Y_qcpp <- computeDR(
Y_train_micro,
C_train_micro,
engine = "qcpp"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.