| coxDKsgplsDR | R Documentation |
This function computes the Cox Model based on PLSR components computed model with
as the response: the Survival time
as explanatory variables: Xplan.
It uses the package sgplsDR to perform group PLSR
fit.
coxDKsgplsDR(Xplan, ...)
## S3 method for class 'formula'
coxDKsgplsDR(
Xplan,
time,
time2,
event,
type,
origin,
typeres = "deviance",
collapse,
weighted,
scaleX = TRUE,
scaleY = TRUE,
ncomp = min(7, ncol(Xplan)),
modepls = "regression",
ind.block.x,
keepX,
alpha.x,
upper.lambda = 10^5,
plot = FALSE,
allres = FALSE,
dataXplan = NULL,
subset,
weights,
model_frame = FALSE,
model_matrix = FALSE,
contrasts.arg = NULL,
kernel = "rbfdot",
hyperkernel,
verbose = FALSE,
...
)
## Default S3 method:
coxDKsgplsDR(
Xplan,
time,
time2,
event,
type,
origin,
typeres = "deviance",
collapse,
weighted,
scaleX = TRUE,
scaleY = TRUE,
ncomp = min(7, ncol(Xplan)),
modepls = "regression",
ind.block.x,
keepX,
alpha.x,
upper.lambda = 10^5,
plot = FALSE,
allres = FALSE,
kernel = "rbfdot",
hyperkernel,
verbose = FALSE,
...
)
Xplan |
a formula or a matrix with the eXplanatory variables (training) dataset |
... |
Arguments to be passed on to |
time |
for right censored data, this is the follow up time. For interval data, the first argument is the starting time for the interval. |
time2 |
The status indicator, normally 0=alive, 1=dead. Other choices
are |
event |
ending time of the interval for interval censored or counting
process data only. Intervals are assumed to be open on the left and closed
on the right, |
type |
character string specifying the type of censoring. Possible
values are |
origin |
for counting process data, the hazard function origin. This option was intended to be used in conjunction with a model containing time dependent strata in order to align the subjects properly when they cross over from one strata to another, but it has rarely proven useful. |
typeres |
character string indicating the type of residual desired.
Possible values are |
collapse |
vector indicating which rows to collapse (sum) over. In
time-dependent models more than one row data can pertain to a single
individual. If there were 4 individuals represented by 3, 1, 2 and 4 rows of
data respectively, then |
weighted |
if |
scaleX |
Should the |
scaleY |
Should the |
ncomp |
The number of components to include in the model. It this is not supplied, min(7,maximal number) components is used. |
modepls |
character string. What type of algorithm to use, (partially)
matching one of "regression", "canonical". See
|
ind.block.x |
a vector of integers describing the grouping of the
X-variables. |
keepX |
numeric vector of length ncomp, the number of variables to keep in X-loadings. By default all variables are kept in the model. |
alpha.x |
The mixing parameter (value between 0 and 1) related to the sparsity within group for the X dataset. |
upper.lambda |
By default |
plot |
Should the survival function be plotted ?) |
allres |
FALSE to return only the Cox model and TRUE for additionnal results. See details. Defaults to FALSE. |
dataXplan |
an optional data frame, list or environment (or object
coercible by |
subset |
an optional vector specifying a subset of observations to be used in the fitting process. |
weights |
an optional vector of 'prior weights' to be used in the
fitting process. Should be |
model_frame |
If |
model_matrix |
If |
contrasts.arg |
a list, whose entries are values (numeric matrices, functions or character strings naming functions) to be used as replacement values for the contrasts replacement function and whose names are the names of columns of data containing factors. |
kernel |
the kernel function used in training and predicting. This
parameter can be set to any function, of class kernel, which computes the
inner product in feature space between two vector arguments (see
kernels). The
|
hyperkernel |
the list of hyper-parameters (kernel parameters). This is a list which contains the parameters to be used with the kernel function. For valid parameters for existing kernels are :
In the case of a Radial Basis kernel function (Gaussian) or
Laplacian kernel, if |
verbose |
Should some details be displayed ? |
If allres=FALSE returns only the final Cox-model. If
allres=TRUE returns a list with the PLS components, the final
Cox-model and the group PLSR model. allres=TRUE is useful for evluating
model prediction accuracy on a test sample.
If allres=FALSE :
cox_DKsgplsDR |
Final Cox-model. |
If
allres=TRUE :
tt_DKsgplsDR |
PLSR components. |
cox_DKsgplsDR |
Final Cox-model. |
DKsgplsDR_mod |
The PLSR model. |
Frédéric Bertrand
frederic.bertrand@lecnam.net
https://fbertran.github.io/homepage/
A group and Sparse Group Partial Least Square approach applied
in Genomics context, Liquet Benoit, Lafaye de Micheaux, Boris Hejblum,
Rodolphe Thiebaut (2016). Bioinformatics.
Deviance residuals-based sparse PLS and sparse kernel PLS regression for censored data, Philippe Bastien, Frederic Bertrand, Nicolas Meyer and Myriam Maumy-Bertrand (2015), Bioinformatics, 31(3):397-404, doi:10.1093/bioinformatics/btu660.
coxph, gPLS
data(micro.censure)
data(Xmicro.censure_compl_imp)
X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),
FUN="as.numeric",MARGIN=2)[1:80,]
X_train_micro_df <- data.frame(X_train_micro)
Y_train_micro <- micro.censure$survyear[1:80]
C_train_micro <- micro.censure$DC[1:80]
(coxDKsgplsDR_fit=coxDKsgplsDR(X_train_micro,Y_train_micro,C_train_micro,
ncomp=6,ind.block.x=c(3,10,15), alpha.x = rep(0.95, 6)))
(coxDKsgplsDR_fit=coxDKsgplsDR(~X_train_micro,Y_train_micro,C_train_micro,
ncomp=6,ind.block.x=c(3,10,15), alpha.x = rep(0.95, 6)))
(coxDKsgplsDR_fit=coxDKsgplsDR(~.,Y_train_micro,C_train_micro,ncomp=6,
dataXplan=X_train_micro_df,ind.block.x=c(3,10,15), alpha.x = rep(0.95, 6)))
rm(X_train_micro,Y_train_micro,C_train_micro,coxDKsgplsDR_fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.