internal-bigPLScox: Internal bigPLScox functions

internal-bigPLScoxR Documentation

Internal bigPLScox functions

Description

These are not to be called by the user.

Author(s)

Frédéric Bertrand
frederic.bertrand@lecnam.net
https://fbertran.github.io/homepage/

References

plsRcox, Cox-Models in a high dimensional setting in R, Frederic Bertrand, Philippe Bastien, Nicolas Meyer and Myriam Maumy-Bertrand (2014). Proceedings of User2014!, Los Angeles, page 152.

Deviance residuals-based sparse PLS and sparse kernel PLS regression for censored data, Philippe Bastien, Frederic Bertrand, Nicolas Meyer and Myriam Maumy-Bertrand (2015), Bioinformatics, 31(3):397-404, doi:10.1093/bioinformatics/btu660.


bigPLScox documentation built on Nov. 18, 2025, 5:06 p.m.