View source: R/predict-big_pls.R
| predict.big_pls_cox | R Documentation |
Predict method for big-memory PLS-Cox models
## S3 method for class 'big_pls_cox'
predict(
object,
newdata = NULL,
type = c("link", "risk", "response", "components"),
comps = NULL,
coef = NULL,
...
)
object |
A model fitted with |
newdata |
Optional matrix, data frame or |
type |
Type of prediction: |
comps |
Integer vector indicating which components to use. Defaults to all available components. |
coef |
Optional coefficient vector overriding the fitted Cox model coefficients. |
... |
Unused. |
Depending on type, either a numeric vector of predictions or a
matrix of component scores.
Maumy, M., Bertrand, F. (2023). PLS models and their extension for big data. Joint Statistical Meetings (JSM 2023), Toronto, ON, Canada.
Maumy, M., Bertrand, F. (2023). bigPLS: Fitting and cross-validating PLS-based Cox models to censored big data. BioC2023 — The Bioconductor Annual Conference, Dana-Farber Cancer Institute, Boston, MA, USA. Poster. https://doi.org/10.7490/f1000research.1119546.1
Bastien, P., Bertrand, F., Meyer, N., & Maumy-Bertrand, M. (2015). Deviance residuals-based sparse PLS and sparse kernel PLS for censored data. Bioinformatics, 31(3), 397–404. doi:10.1093/bioinformatics/btu660
Bertrand, F., Bastien, P., Meyer, N., & Maumy-Bertrand, M. (2014). PLS models for censored data. In Proceedings of UseR! 2014 (p. 152).
big_pls_cox(), big_pls_cox_gd(), select_ncomp(),
computeDR().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.